<?php
$lang['abbr_length'] = 'l';
$lang['abbr_width'] = 'L';
$lang['abbr_height'] = 'H';
$lang['add'] = 'Ajouter';
$lang['addcategory'] = 'Ajouter une cat&eacute;gorie';
$lang['addfielddef'] = 'Ajouter un champ';
$lang['adjustable'] = 'Ajustable';
$lang['addproduct'] = 'Ajouter un produit';
$lang['add_attrib_set'] = 'Ajouter un attribut';
$lang['add_category_field'] = 'Associe un champ &agrave; la cat&eacute;gorie: &quot;%s&quot;';
$lang['add_hierarchy_item'] = 'Ajoute une hi&eacute;rarchie d&#039;article';
$lang['add_option'] = 'Ajouter une option d&#039;attribut';
$lang['admin_only'] = 'Seuls les administrateurs peuvent voir cet attribut?';
$lang['align_ul'] = 'Haut gauche';
$lang['align_uc'] = 'Haut centre';
$lang['align_ur'] = 'Haut droit';
$lang['align_ml'] = 'Milieu gauche';
$lang['align_mc'] = 'Centre';
$lang['align_mr'] = 'Milieu droit';
$lang['align_ll'] = 'Bas gauche';
$lang['align_lc'] = 'Bas centre';
$lang['align_lr'] = 'Bas droit';
$lang['all'] = 'Tous';
$lang['allcategories'] = 'Toutes les cat&eacute;gories';
$lang['any'] = 'Aucun';
$lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r?';
$lang['areyousure_deleteproduct'] = '&Ecirc;tes-vous s&ucirc;r de vouloir supprimer ce produit, et toute l&#039;information l&#039;accompagnant ?';
$lang['ascending'] = 'Ascendant';
$lang['attribute_name'] = 'Nom de l&#039;attribut';
$lang['automatic'] = 'Automatique';
$lang['byhierarchytemplates'] = 'Gabarits de hi&eacute;rarchie';
$lang['byhierarchytemplate_addedit'] = 'Ajouter/Editer un gabarit de hi&eacute;rarchie';
$lang['cancel'] = 'Annuler';
$lang['categories'] = 'Cat&eacute;gories';
$lang['category'] = 'Cat&eacute;gorie';
$lang['categoryexists'] = 'Une cat&eacute;gorie du m&ecirc;me nom existe d&eacute;j&agrave;';
$lang['categorylisttemplates'] = 'Gabarits de la liste des cat&eacute;gories';
$lang['categorylisttemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit de liste de cat&eacute;gories';
$lang['centimeters'] = 'Centim&egrave;tres';
$lang['checkbox'] = 'Case &agrave; cocher';
$lang['confirm_copyattributes'] = 'Aany existing attribute sets for this product will be removed. Are you sure you want to continue?';
$lang['confirm_delete_hierarchy_node'] = 'Confirmez-vous la suppression de cet &eacute;l&eacute;ment ? Tous les produits qui l&#039;utilisent ne figureront plus dans la hi&eacute;rarchie.';
$lang['confirm_import'] = 'Voulez-vous r&eacute;ellement effectuer cette action ?\n\nDes param&egrave;tres incorrects ou un fichier de configuration invalide peuvent corrompre le catalogue de produits et le rendre inutilisable.';
$lang['copy'] = 'Copier';
$lang['copy_attrib_sets'] = 'Copy Attribute Sets';
$lang['copy_category'] = 'Copier la cat&eacute;gorie';
$lang['createddate'] = 'Date de cr&eacute;ation';
$lang['current_value'] = 'Valeur actuelle';
$lang['data'] = 'Donn&eacute;es';
$lang['default'] = 'D&eacute;faut';
$lang['defaulttemplates'] = 'Gabarits par d&eacute;faut';
$lang['default_template_notice'] = '<strong>Note:</strong>Le contenu de ces zones d&#039;&eacute;dition sont utilis&eacute;s pour d&eacute;terminer le contenu par d&eacute;faut des gabarits quand vous cliquez sur &quot;Ajout d&#039;un nouveau gabarit&quot; dans l&#039;onglet correspondant. La modification du contenu dans ces zones d&#039;&eacute;dition n&#039;aura pas d&#039;effet imm&eacute;diat sur votre site';
$lang['delete'] = 'Supprimer';
$lang['delete_attribset'] = 'Supprimer l&#039;attribut';
$lang['delete_hierarchy_item'] = 'Supprimer un &eacute;l&eacute;ment de hi&eacute;rarchie';
$lang['descending'] = 'Descendant';
$lang['description'] = 'Description ';
$lang['destination'] = 'Destination ';
$lang['details'] = 'D&eacute;tails';
$lang['detailtemplates'] = 'Gabarits d&eacute;tails';
$lang['detailtemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit d&eacute;tails';
$lang['dimensions'] = 'Dimensions ';
$lang['disabled'] = 'D&eacute;sactiv&eacute;';
$lang['draft'] = '&Eacute;bauche';
$lang['dropdown'] = 'Menu d&eacute;roulant';
$lang['dropdown_options'] = 'Options du menu d&eacute;roulant <em>(uniquement pour les champs de type Menu d&eacute;roulant)</em><br/><br/><em>(une option de menu par ligne)</em>';
$lang['edit'] = 'Editer';
$lang['edit_attribset'] = 'Editer les Attributs';
$lang['edit_attribsets'] = '&Eacute;diter les sets d&#039;attributs';
$lang['edit_attribsets_for'] = '&Eacute;diter les sets d&#039;attributs pour';
$lang['edit_attributes'] = '&Eacute;diter les attributs';
$lang['edit_category'] = 'Editer la cat&eacute;gorie';
$lang['edit_category_fields'] = 'Editer les champs de la cat&eacute;gorie';
$lang['edit_hierarchy_item'] = 'Editer l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie';
$lang['error_attribset_exists'] = 'Il y a d&eacute;j&agrave; un attribut du m&ecirc;me nom';
$lang['error_duplicate_sku'] = 'Plusieurs Valeurs SKU identiques trouv&eacute;es';
$lang['error_fieldvalue_empty'] = 'Une valeur doit &ecirc;tre indiqu&eacute;e';
$lang['error_fileformat'] = 'Probl&egrave;me de format de fichier';
$lang['error_filenotfound'] = 'Fichier introuvable';
$lang['error_fileopen'] = 'Erreur &agrave; l&#039;ouverture du fichier %s';
$lang['error_invalidparent'] = 'Parent invalide (un element de hi&eacute;rarchie ne peut &ecirc;tre son propre parent)';
$lang['error_invalid_name'] = 'La valeur du champ personnalis&eacute; est invalide (seuls les caract&egrave;res alphanum&eacute;riques sont autoris&eacute;s)';
$lang['error_invalid_value'] = 'Invalid value specified';
$lang['error_missingparam'] = 'Un param&egrave;tre requis est manquant ou invalide';
$lang['error_nameused'] = 'Un &eacute;l&eacute;ment portant ce nom existe d&eacute;j&agrave;';
$lang['error_nofieldtype'] = 'Choisisser le type du champ';
$lang['error_noname'] = 'Un nom doit &ecirc;tre indiqu&eacute;';
$lang['error_onesubscriptionfield'] = 'Un seul champs de souscription est autoris&eacute;';
$lang['error_permissiondenied'] = 'Permission refus&eacute;e';
$lang['error_product_aliasused'] = 'L&#039;alias sp&eacute;cifi&eacute; est d&eacute;j&agrave; utilis&eacute;';
$lang['error_product_nameused'] = 'Un produit portant ce nom existe d&eacute;j&agrave;';
$lang['error_product_notfound'] = 'Le produit d&eacute;sir&eacute; n&#039;a pas pu &ecirc;tre retrouv&eacute;';
$lang['error_product_skuused'] = 'Cette valeur SKU est d&eacute;j&agrave; utilis&eacute;e par un autre produit';
$lang['error_price_adjustment'] = 'La valeur d&#039;ajustement du prix est invalide pour l&#039;objet %s';
$lang['error_upload_failed'] = 'L&#039;envoi du fichier a &eacute;chou&eacute;: %s';
$lang['expire_six_months'] = 'Apr&egrave;s Six Mois';
$lang['expire_one_year'] = 'Apr&egrave;s Un An';
$lang['expire_two_year'] = 'Apr&egrave;s Deux Ans';
$lang['extra1'] = 'Champ suppl&eacute;mentaire 1';
$lang['extra2'] = 'Champ suppl&eacute;mentaire 2';
$lang['field'] = 'Champ';
$lang['fielddef'] = 'D&eacute;finition d&#039;un champ';
$lang['fielddefs'] = 'D&eacute;finitions des champs';
$lang['file'] = 'Fichier';
$lang['filters'] = 'Filtres';
$lang['firstpage'] = '&amp;lt;&amp;lt;';
$lang['general_settings'] = 'Param&egrave;tres g&eacute;n&eacute;raux';
$lang['go'] = 'Envoyer';
$lang['help'] = '<h3>Que fait ce module ?</h3>
<p>Ce module permet de d&eacute;finir, d&#039;organiser et d&#039;afficher les donn&eacute;es de produits et des cat&eacute;gories associ&eacute;es. Il peut s&#039;int&eacute;grer dans une solution de commerce &eacute;lectronique, mais aussi fonctionner de mani&egrave;re autonome. Les produits peuvent appartenir &agrave; une ou plusieurs cat&eacute;gories. Le prix et le poids des produits est g&eacute;r&eacute; par le module, et des informations suppl&eacute;mentaires (attributs) peuvent &ecirc;tre ajout&eacute;es. Chaque attribut peut d&eacute;finir une modification du prix du produit.  Un indicateur permet de d&eacute;finir si par d&eacute;faut un produit est ou non tax&eacute;.</p>
  <p>Le module permet d&#039;attacher jusqu&#039;&agrave; deux images &agrave; un produit, de d&eacute;finir des champs personnalis&eacute;s publics ou priv&eacute;s.</p>
<h3>Fonctions:</h3>
<ul>
  <li>Types d&#039;affichage</li>
    <ul>
      <li>Affichage r&eacute;sum&eacute;</li>
      <li>Affichage par cat&eacute;gorie</li>
      <li>Affichage d&eacute;taill&eacute;</li> 
      <li>Affichage hi&eacute;rarchique</li>
    </ul>
  <li>Tous les gabarits sont stock&eacute;s dans la base de donn&eacute;es</li>
  <p>Pour chaque type d&#039;affichage plusieurs gabarits peut &ecirc;tre cr&eacute;&eacute;s, avec un gabarit par d&eacute;faut, et des gabarits pass&eacute;s en param&egrave;tre de chacun des type d&#039;affichage.</p>
  <li>Tri et affichage page par page dans dans l&#039;affichage r&eacute;sum&eacute;</li>
  <li>Les produits peuvent figurer dans plusieurs cat&eacute;gories</li>
  <li>Possibilit&eacute; de d&eacute;finir autant d&#039;attributs personnalis&eacute;s que n&eacute;cessaire, y compris de type image ou fichier.</li>
  <li>Cr&eacute;ation automatique des images miniatures</li>
  <li>Attributs d&eacute;finis par l&#039;administrateur</li>
  <li>Attributs de produits (avec possibilit&eacute; d&#039;ajustement du prix)</li>
  <li>Poids et indicateur de taxation (pour l&#039;int&eacute;gration &agrave; un syst&egrave;me de commerce &eacute;lectronique)</li>
  <li>Les produits ont un statut de publication (brouillon/publi&eacute;), qui permet de les masquer dans la partie publique si besoin est.</li>
  <li>Support des URL simples</li>
  <li><strong>Et bien plus encore...</strong></li>
</ul>

<h3>Comment l&#039;utiliser ?</h3>
<ul>
<li>D&eacute;finir les pr&eacute;f&eacute;rences</li>
<p>Ce n&#039;est en principe qu&#039;une formalit&eacute;. Vous devez indiquer l&#039;unit&eacute; de poids et le code mon&eacute;taire que vous souhaitez utiliser.</p>

<li>Configurer les utilisateurs du catalogue et leurs permissions</li>
<p>Ce module utilise la permission &#039;Modifier les gabarits&#039; (ModifyTemplates) pour attribuer l&#039;autorisation de modifier les divers gabarits du module.  De m&ecirc;me, la permission &#039;Modifier les pr&eacute;f&eacute;rences du site&#039; (Modify Site Preferences) est n&eacute;cessaire pour modifier les pr&eacute;f&eacute;rences du module. Pour pouvoir modifier la d&eacute;finition des attributs, les cat&eacute;gories ou les produits, les utilisateurs doivent avoir la permission &#039;Modifier les Produits&#039; (Modify Products).</p>

<li>Cr&eacute;er des cat&eacute;gories (optionnel)</li>
<p>Cette &eacute;tape n&#039;est pas indispensable, mais vous devriez d&eacute;finir des cat&eacute;gories maintenant pour &eacute;viter plus tard d&#039;avoir &agrave; revenir modifier chaque produit si vous changez d&#039;avis. Pour ajouter une cat&eacute;gorie, cliquer sur l&#039;onglet &#039;Cat&eacute;gories&#039; du Gestionnaire de Produits, puis sur &#039;Ajouter une cat&eacute;gorie&#039;. Vous devrez ensuite indiquer le nom de cette nouvelle cat&eacute;gorie.</p>

<li>Cr&eacute;er des attributs (optionnel)</li>
<p>Cette &eacute;tape n&#039;est pas indispensable si le module r&eacute;pond exactement &agrave; votre besoin. Par contre, si vous souhaitez d&eacute;finir des informations suppl&eacute;mentaires pour chaque produit, vous devez cr&eacute;er ces attributs.  La cr&eacute;ation d&#039;attributs ressemble &agrave; la cr&eacute;ation de cat&eacute;gories, mais vous devez indiquer un peu plus d&#039;informations.</p>
<p>Actuellement, six type d&#039;attributs sont disponibles: &#039;textbox&#039; (champ de texte),&#039;checkbox&#039; (case &agrave; cocher), &#039;textarea&#039; (zone de texte), dropdown (menu d&eacute;roulant), &#039;image&#039; (fichier image) et &#039;file&#039; (fichier quelconque).  Choisissez un type d&#039;attribut, donnez-lui un nom, un label d&#039;affichage, et indiquez si cet attribut est visible ou non dans la partie publique.</p>

<li>Cr&eacute;er des produits</li>
<p>Vous devez cr&eacute;er des produits pour que ce module puisse afficher quelque chose dans la partie publique du site. Pour chacun des produits, indiquez un nom, un prix (optionnel) un poids (optionnel), un statut (publi&eacute;/brouillon), et &eacute;ventuellement d&#039;autres informations. Vous pouvez aussi indiquer si le produit est soumis aux taxes.</p>
<p>Si vous avez cr&eacute;&eacute; des cat&eacute;gories, la liste de ces cat&eacute;gorie est affich&eacute;es, et vous pouvez en s&eacute;lectionner la ou les cat&eacute;gories auxquelles ce produit appartient.</p>
<p>Si des attributs ont &eacute;t&eacute; d&eacute;finis, les champs de saisie associ&eacute;s sont affich&eacute;s, et vous pourrez saisir les valeurs de chaque attribut. La saisie des attributs est optionnelle.</p>

<li>Ajoutez les balises du module dans vos gabarits et/ou dans vos pages</li>

<p>Il suffit d&#039;ins&eacute;rer la balise <strong>{Products}</strong> dans le contenu d&#039;une de vos pages, ou dans un de vos gabarits.</p>
<p>Pour utiliser d&#039;autres fonctions, vous devez ajouter un ou plusieurs param&egrave;tres &agrave; la balise <strong>{Products}</strong>. La liste de ces param&egrave;tres figure un peu plus bas. Par exemple, pour afficher la liste des produits appartenant &agrave; une cat&eacute;gorie, utilisez une balise comme <code>{Products category=&#039;nom_de_la_categorie&#039;}</code></p>
</ul>
<h3>Assistance</h3>
<p>Ce module est fourni sans aucune assistance commerciale. Cependant, vous pouvez tout de m&ecirc;me obtenir de l&#039;aide:</p>
<ul>
<li>Pour obtenir la derni&egrave;re version de ce module, consulter la FAQ, ou signaler un bug, rendez-vous sur la <a href="http://dev.cmsmadesimple.org">Developers Forge</a> de CMS Made Simple, et faites une recherche de &#039;Products&#039;.</li>
<li>Pour obtenir une assistance commerciale, contactez par mail <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>, l&#039;auteur de ce module.</li>
<li>Les <a href="http://forum.cmsmadesimple.org">Forums CMS Made Simple</a> sont aussi une pr&eacute;ciseuse source d&#039;informations.</li>
<li>Pour des questions simples est un support technique de base, vous pouvez contacter l&#039;auteur du module sur <a href="irc://irc.freenode.net/#cms">le channel IRC CMS</a>.</li>
</ul>';
$lang['hierarchy'] = 'Hierarchie';
$lang['hierarchy_position'] = 'Position dans la hi&eacute;rarchie';
$lang['id'] = 'Id ';
$lang['imagetext'] = 'Image ';
$lang['image_handling_settings'] = 'Param&egrave;tres de manipulation des images';
$lang['import_from_csv'] = 'Importer les produits depuis un fichier CSV';
$lang['inches'] = 'Pouces';
$lang['include_children'] = 'Avec les descendants ?';
$lang['info_alnumonly'] = 'Caract&egrave;res alphanum&eacute;riques uniquement. Pas d&#039;espaces, de guillemets ou de combinaisons autres que lettres et chiffres.';
$lang['info_attribtemplate'] = 'Les variables possibles sont : {$attrib_text},{$attrib_adjust},{$currency_symbol}';
$lang['info_attributes_copied'] = 'Attributes Copied';
$lang['info_autowatermark'] = 'La configuration des filigranes est celle du module CGExtensions';
$lang['info_batchsize'] = 'Indiquez le nombre de lignes &agrave; traiter &agrave; chaque it&eacute;ration. D&egrave;s qu&#039;une it&eacute;ration est termin&eacute;e, le syst&egrave;me d&#039;importation d&eacute;marre la suivante. Si des probl&egrave;mes de m&eacute;moire ou de temps d&#039;ex&eacute;cution se produisent, r&eacute;duisez cette valeur, ou consultez le fournisseur de votre h&eacute;bergement.';
$lang['info_cart_module_params'] = 'Ces param&egrave;tres sont pass&eacute;s au module panier s&eacute;lectionn&eacute;, &agrave; partir de la description et du r&eacute;sum&eacute; du produit.';
$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
$lang['info_createfields'] = 'Cr&eacute;er automatiquement les champs inconnus ? <em>(cr&eacute;ation de champs de type texte)</em>';
$lang['info_createcategories'] = 'Cr&eacute;er automatiquement les cat&eacute;gories de produits pr&eacute;sentes dans le fichier CSV, si elles n&#039;existent pas d&eacute;j&agrave;';
$lang['info_createhierarchy'] = 'Cr&eacute;er automatiquement les &eacute;l&eacute;ments de hi&eacute;rarchie de produits pr&eacute;sentes dans le fichier CSV, si ils n&#039;existent pas d&eacute;j&agrave;';
$lang['info_decimal_units'] = 'Utiliser le point (.) comme s&eacute;parateur d&eacute;cimal. Exemple:  <strong>5.25</strong>';
$lang['info_delimiter'] = 'Indiquer le catact&egrave;re (ou les caract&egrave;res) s&eacute;parateurs de champs';
$lang['info_duplicateproducts'] = 'Traitement a appliquer aux produits dont le nom existe d&eacute;j&agrave; dans le fichier CSV';
$lang['info_fielddefs_tab'] = '<strong>Note: </strong> Les champs d&eacute;finis ici sont communs &agrave; tous les produits';
$lang['info_fieldproblems'] = 'Une erreur est survenue lors du traitement d&#039;un ou plusieurs champs personnalis&eacute;s. L&#039;action s&#039;est termin&eacute;e correctement, mais vous devriez chercher la cause de l&#039;erreur.';
$lang['info_handleimages'] = 'Lors de l&#039;importation, si un nom de fichier image est trouv&eacute; dans une colonne, faut-il le d&eacute;placer de son r&eacute;pertoire d&#039;origine, lui ajouter un filigrane, cr&eacute;er une miniature, et changer le type du champ associ&eacute; en champ &quot;image&quot; ?';
$lang['info_imagepath'] = 'Chemin (relatif au r&eacute;pertoire uploads) des images r&eacute;f&eacute;renc&eacute;es par le fichier import&eacute; ';
$lang['info_import_test_passed'] = 'Apr&egrave;s un examen pr&eacute;liminaire, le fichier semble correct.<br/>Cependant, il se peut qu&#039;il contienne tout de m&ecirc;me des erreurs qui ne pourront &ecirc;tre d&eacute;tect&eacute;es que lors de l&#039;importation.';
$lang['info_price_adjustment'] = 'Les valeurs valides sont +-*#.##';
$lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
$lang['info_publicfield'] = 'Les champs publics sont visibles par les utilisateurs.';
$lang['label'] = '&Eacute;tiquette';
$lang['label_skip'] = 'Ignorer';
$lang['label_overwrite'] = 'Ecraser';
$lang['lastpage'] = '&amp;gt;&amp;gt;';
$lang['last_modified'] = 'Derni&egrave;re modification';
$lang['logotext'] = 'Logo ';
$lang['maxlength'] = 'Longeur Maximale <em>(applicable seulement aux champs textbox)</em>';
$lang['modifieddate'] = 'Date de modification';
$lang['module_description'] = 'Un module de gestion d&#039;un catalogue de produits, de leurs prix, images, etc. Permet aussi aux utilisateurs de remplir un panier d&#039;achat.';
$lang['move_down'] = 'Descendre';
$lang['move_up'] = 'Remonter';
$lang['name'] = 'Nom';
$lang['needpermission'] = 'Vous n&#039;avez pas la permission requise&nbsp;: %s';
$lang['new_category_name'] = 'Nouveau nom de cat&eacute;gorie';
$lang['nextpage'] = '&amp;gt;';
$lang['no'] = 'Non';
$lang['nonamegiven'] = 'Vous n&#039;avez pas donn&eacute; de nom';
$lang['none'] = 'Aucun';
$lang['of'] = 'de';
$lang['page'] = 'Page ';
$lang['page_of'] = 'Page %s sur %s';
$lang['page_limit'] = 'El&eacute;ments par page';
$lang['param_action'] = 'Sp&eacute;cifie le comportement du module. Les valeurs possibles sont&nbsp;:
<ul>
  <li>hierarchy - Afficher la hi&eacute;rarchie de produits</li>
  <li>categorylist - Afficher une liste de cat&eacute;gories de produits</lI
  <li><em>default</em> - Affiche le sommaire des produits</li>
  <li>detail - Affiche le d&eacute;tail d&#039;un produit donn&eacute;</li>
  <li>fieldlist - Affiche la liste des valeurs du champ sp&eacute;cifi&eacute;.
     <p>
&nbsp;&nbsp;&nbsp;&nbsp;- Cette action peut &ecirc;tre utilis&eacute;e pour cr&eacute;er une navigation &agrave; partir des valeurs d&#039;un champ sp&eacute;cifique. Par exemple, vous pouvez cr&eacute;er une liste d&eacute;roulante personnalis&eacute;e appel&eacute;e &quot;Couleur&quot; et alors cr&eacute;er une navigation bas&eacute;e sur les diff&eacute;rentes couleurs.
     </p>
  </li>
  <li>search - Afficher un formulaire de recherche de produits multi-crit&egrave;res</li>
</ul>';
$lang['param_category'] = 'Lors de l&#039;utilisation <em>par d&eacute;faut</em> en mode sommaire, ce param&egrave;tre, qui devrait correspondre au nom d&#039;une cat&eacute;gorie existante, sera utilis&eacute; pour afficher seulement les entr&eacute;es qui sont dans cette cat&eacute;gorie (une liste s&eacute;par&eacute;e par des virgules peut &ecirc;tre fournie)';
$lang['param_categorylisttemplate'] = 'Utile seulement avec l&#039;action categorylist, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
$lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
$lang['param_detailpage'] = 'Sp&eacute;cifie l&#039;id ou l&#039;alias de la page qui doit &ecirc;tre utilis&eacute;e pour afficher le d&eacute;tail.';
$lang['param_detailtemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit devrait &ecirc;tre utilis&eacute; pour l&#039;affichage en mode d&eacute;tails. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
$lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
$lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
$lang['param_hierarchy'] = 'Utilis&eacute; seulement avec l&#039;action 
<em>default</em>, ce param&egrave;tre indique que seuls les produits appartenant &agrave; cet &eacute;l&eacute;ment de hi&eacute;rarchie doivent &ecirc;tre affich&eacute;s.  Des jokers peuvent &ecirc;tre utilis&eacute;s pour &eacute;tendre l&#039;affichage aux parent ou enfants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie indiqu&eacute;.  Par exemple {Products hierarchy=&#039;potirons*&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux descendants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;.  De m&ecirc;me, {Products hierarchy=&#039;*potirons&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux parents de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;';
$lang['param_hierarchytemplate'] = 'Ce param&egrave;tre indique le gabarit &agrave; utiliser lors de l&#039;affichage de la hi&eacute;rarchie. Le gabarit de hi&eacute;rarchie par d&eacute;faut est utilis&eacute; si ce param&egrave;tre est absent ou vide.';
$lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
$lang['param_pagelimit'] = 'Utilis&eacute; seulement avec l&#039;action <em>par d&eacute;faut</em>, ce param&egrave;tre sp&eacute;cifie combien d&#039;articles doivent &ecirc;tre list&eacute;s sur chaque page.';
$lang['param_parent'] = 'Utilis&eacute; seulement avec l&#039;action <em>hierarchy</em>, ce param&egrave;tre indique quel est  l&#039;ID du premier &eacute;l&eacute;ment de la hi&eacute;rarchie &agrave; afficher';
$lang['param_productid'] = 'Utilis&eacute; seulement avec l&#039;action d&eacute;tail, ce param&egrave;tre indique quels produits utiliser pour l&#039;affichage.';
$lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
$lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
$lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
$lang['param_showall'] = 'Applicable only to the categorylist and fieldlist actions, if this parameter is set to a non 0 integer value all categories (even those without products) will be displayed.';
$lang['param_sortorder'] = 'Sp&eacute;cifie l&#039;ordre des champs tri&eacute;s en mode sommaire. Les valeurs possibles sont:
<ul>
  <li><strong>asc</strong> -- Ordre ascendant</li>
  <li>desc -- Order descendant</li>
</ul>';
$lang['param_sortby'] = 'Applicable seulement en mode sommaire, ce param&egrave;tre d&eacute;termine le tri des entr&eacute;es. Les valeurs possibles sont:
<ul>
  <li><strong>product_name</strong></li>
  <li>phone</li>
  <li>fax</li>
  <li>email</li>
  <li>website -- L&#039;url du site internet</li>
  <li>created -- La date de cr&eacute;ation de l\&#039;entr&eacute;e</li>
  <li>modified --  La date de modification de l\&#039;entr&eacute;e</li>
</ul>';
$lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
$lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
$lang['param_summarytemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit doit &ecirc;tre utilis&eacute; en affichage mode sommaire. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
$lang['parent'] = 'Parent ';
$lang['postinstall'] = 'Le module Produits a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
$lang['postuninstall'] = 'Le module Produits a &eacute;t&eacute; supprim&eacute;, ainsi que toutes les donn&eacute;es associ&eacute;es.';
$lang['preferences'] = 'Pr&eacute;f&eacute;rences';
$lang['preuninstall'] = 'Supprimer ce module va aussi supprimer toutes les donn&eacute;es associ&eacute;es, &ecirc;tes-vous s&ucirc;r de vouloir continuer?';
$lang['price'] = 'Prix';
$lang['price_adjustment'] = 'Ajustement de prix';
$lang['prevpage'] = '&amp;lt;';
$lang['product'] = 'Produit';
$lang['productname'] = 'Nom du produit';
$lang['products'] = 'Gestionnaire de produits';
$lang['product_detail_settings'] = 'Param&egrave;tres D&eacute;tails du produit';
$lang['product_editing_settings'] = 'Product Editing Settings';
$lang['product_summary_settings'] = 'Product Summary Settings';
$lang['product_hierarchy'] = 'Hierarchie de produits';
$lang['product_manager'] = 'Gestionnaire de produits';
$lang['progress'] = 'Progression';
$lang['prompt'] = 'Libell&eacute;';
$lang['prompt_add_attribset'] = 'Ajouter/Modifier les param&egrave;tres des attributs';
$lang['prompt_allowed_filetypes'] = 'Extensions de fichiers autoris&eacute;es (pour les champs de type fichier)';
$lang['prompt_allowed_imagetypes'] = 'Extensions de fichiers image autoris&eacute;es (pour les champs de type image)';
$lang['prompt_attribtemplate'] = 'Gabarit d&#039;affichage des valeurs d&#039;attributs de produits dans la liste d&eacute;roulante';
$lang['prompt_autothumbnail'] = 'Cr&eacute;er automatiquement les miniatures des images';
$lang['prompt_autothumbnail_size'] = 'Taille maximum (c&ocirc;t&eacute; le plus long) de la miniature.';
$lang['prompt_autopreviewimg'] = 'Cr&eacute;er automatiquement une pr&eacute;visualisation de l&#039;image';
$lang['prompt_autopreviewimg_size'] = 'Taille maximum (c&ocirc;t&eacute; le plus long) de la pr&eacute;visualisation de l&#039;image.';
$lang['prompt_autowatermark'] = 'Placer automatiquement un filigrane dans les images';
$lang['prompt_applicable'] = 'Activer par d&eacute;faut pour tous les nouveaux produits';
$lang['prompt_batchsize'] = 'Nombre de lignes import&eacute;es &agrave; chaque it&eacute;ration';
$lang['prompt_cart_module'] = 'Module Panier (Cart)';
$lang['prompt_cart_module_params'] = 'Param&egrave;tre du module panier';
$lang['prompt_createcategories'] = 'Cr&eacute;er des cat&eacute;gories';
$lang['prompt_createfields'] = 'Cr&eacute;er les champs des produits ?';
$lang['prompt_createhierarchy'] = 'Cr&eacute;er une hi&eacute;rarchie de produits';
$lang['prompt_csvfile'] = 'Envoyer un fichier CSV';
$lang['prompt_currencycode'] = 'Code mon&eacute;taire';
$lang['prompt_currencysymbol'] = 'Monnaie';
$lang['prompt_default_status'] = 'Statut par d&eacute;faut des nouveaux produits';
$lang['prompt_default_taxable'] = 'Tous les produits sont tax&eacute;s par d&eacute;faut';
$lang['prompt_deleteproductfiles'] = 'Effacer les fichiers attach&eacute;s au produit lors de sa suppression ?';
$lang['prompt_delimiter'] = 'S&eacute;parateur de champs';
$lang['prompt_detailpage'] = 'Page d&eacute;tail par d&eacute;faut';
$lang['prompt_detailsfor'] = 'D&eacute;tails pour %s';
$lang['prompt_duplicateproducts'] = 'Mode de gestion des produits en doublon ?';
$lang['prompt_false'] = 'Faux';
$lang['prompt_handleimages'] = 'G&eacute;rer les images ?';
$lang['prompt_imagepath'] = 'Chemin des images';
$lang['prompt_lengthunits'] = 'Unit&eacute;s de longueur';
$lang['prompt_notfound_behavior'] = 'Quelle action doit &ecirc;tre r&eacute;alis&eacute;e lorsqu&#039;un produit ne peut &ecirc;tre affich&eacute;';
$lang['prompt_notfound_404'] = 'G&eacute;n&eacute;rer une erreur 404';
$lang['prompt_notfound_301'] = 'G&eacute;n&eacute;rer une redirection 301';
$lang['prompt_notfound_errormsg'] = 'Afficher un message d&#039;erreur';
$lang['prompt_notfound_msg'] = 'Message d&#039;erreur lorsqu&#039;un produit n&#039;est pas trouv&eacute;';
$lang['prompt_notfound_page'] = 'Page pour faire les redirections permanentes';
$lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits';
$lang['prompt_products_matching'] = 'Produits correspondant &agrave; %s';
$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
$lang['prompt_summarysortorder'] = 'Ordre de tri par d&eacute;faut en mode sommaire';
$lang['prompt_summarysorting'] = 'Champ de tri par d&eacute;faut en mode sommaire';
$lang['prompt_template'] = 'Source du gabarit';
$lang['prompt_true'] = 'Vrai';
$lang['prompt_urlprefix'] = 'Pr&eacute;fixe &agrave; utiliser sur toutes les URL cibl&eacute;es de ce module';
$lang['prompt_use_detailpage_for_search'] = 'Utiliser cette page pour les r&eacute;sultats de recherche<em>(remplace le param&egrave;tre &#039;page des r&eacute;sultats de la recherche&#039; dans le module search)</em>';
$lang['prompt_usehierpathurls'] = 'Utiliser le &#039;Hierarchy Path&#039; dans les urls des d&eacute;tails de produit';
$lang['prompt_weightunits'] = 'Unit&eacute;s de poids';
$lang['public'] = 'Est-ce un champ public?';
$lang['published'] = 'Publi&eacute;';
$lang['random'] = 'Au hasard';
$lang['resettofactory'] = 'R&eacute;initialiser aux valeurs par d&eacute;faut';
$lang['return'] = 'Retour';
$lang['return_to_top'] = 'Retour en haut de page';
$lang['root'] = 'Racine';
$lang['search_description'] = 'Search Property Description';
$lang['search_expr'] = 'La requ&ecirc;te devra elle correspondent &agrave; la totalit&eacute;, ou au moins &agrave; l&#039;un des tests ci-dessous?';
$lang['search_name'] = 'Search Property Name';
$lang['search_price'] = 'Gamme de prix';
$lang['searchtemplate_addedit'] = 'Ajouter/Modifier le gabarit de formulaire de recherche';
$lang['searchtemplates'] = 'Gabarit de recherche';
$lang['select_one'] = 'Choisir...';
$lang['sku'] = 'SKU (identifiant de quantit&eacute; en stock)';
$lang['sort_by'] = 'Tri par';
$lang['sort_order'] = 'Ordre de tri';
$lang['source'] = 'Source';
$lang['status'] = 'Statut';
$lang['submit'] = 'Soumettre';
$lang['subscription'] = 'Abonnement';
$lang['subscr_expiry'] = 'Expir&eacute;';
$lang['subscr_expiry2'] = 'Expir&eacute;s';
$lang['subscr_monthly'] = 'Mensuel';
$lang['subscr_delperiod'] = 'Fr&eacute;quence de livraison';
$lang['subscr_delperiod2'] = 'Livr&eacute;';
$lang['subscr_payperiod'] = 'Fr&eacute;quence de paiement';
$lang['subscr_payperiod2'] = 'Pay&eacute;';
$lang['subscr_quarterly'] = 'Trimestriel';
$lang['subscr_semianually'] = 'Semi-Annuel';
$lang['subscr_yearly'] = 'Annuel';
$lang['summarytemplates'] = 'Gabarits de sommaire';
$lang['summarytemplate_addedit'] = 'Ajout ou &eacute;dition d&#039;un gabarit de sommaire';
$lang['taxable'] = 'Taxable ';
$lang['test'] = 'Test ';
$lang['textarea'] = 'Zone de texte';
$lang['textbox'] = 'Champ texte';
$lang['title_byhierarchy_dflttemplate'] = 'Gabarit de hi&eacute;rarchie par d&eacute;faut';
$lang['title_categorylist_dflttemplate'] = 'Gabarit par d&eacute;faut pour une nouvelle liste de cat&eacute;gories';
$lang['title_detail_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;affichage du d&eacute;tail';
$lang['title_search_dflttemplate'] = 'Gabarit par d&eacute;faut des Nouvelles recherches';
$lang['title_summary_dflttemplate'] = 'Gabarit par d&eacute;faut pour l&#039;affichage du sommaire';
$lang['type'] = 'Type ';
$lang['update'] = 'Mise &agrave; jour';
$lang['upload'] = 'Choisissez le fichier &agrave; envoyer';
$lang['url_alias'] = 'Alias URL ';
$lang['valid'] = 'Valide';
$lang['value'] = 'Valeur';
$lang['values'] = 'Valeurs';
$lang['view'] = 'Vue';
$lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s &agrave; afficher dans le tableau';
$lang['watermark_location'] = 'Emplacement du filigrane';
$lang['weight'] = 'Poids';
$lang['yes'] = 'Oui';
$lang['utmz'] = '156861353.1291710225.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-747226238-1292160330212';
$lang['utma'] = '156861353.1179877785.1291710225.1291927574.1292160330.5';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1292160330';
?>